@@ -53,6 +53,8 @@ define("SELECT_GROUP_SQL", "SELECT loggroup.group_id,loggroup.group_name,loginfo
  **********************************************************/
 function set_tag_data($post, &$tag)
 {
+    global $web_conf;
+
     /*   */
     $javascript = <<<EOD
     function allSubmit(url, page) {
@@ -93,59 +95,25 @@ EOD;
         $tag["<<IF>>"] = escape_html($_POST["interface"]);
     }
 
-    /* ϻ֥쥯ȥܥå */
-    $option = array("0" => "",
-                    "1" => "",
-                    "2" => "",
-                    "3" => "",
-                    "4" => "",
-                    "5" => ""
-                   );
-    if (isset($_POST["starttime"]) === TRUE) {
-        $starttime =$_POST["starttime"];
-    } else {
-        $starttime = array("0" => -2,
-                           "1" => -2,
-                           "2" => -2,
-                           "3" => -2,
-                           "4" => -2,
-                           "5" => -2
-                          );
+    $tag["<<STARTDATE>>"] = date("Y/m/d 00:00:00");
+    if (isset($_POST["startdate"]) === TRUE) {
+        $tag["<<STARTDATE>>"] = $_POST["startdate"];
     }
-    make_time_select_option($starttime, $option);
-    $tag["<<START_YEAR_OPTION>>"]   = $option["0"];
-    $tag["<<START_MONTH_OPTION>>"]  = $option["1"];
-    $tag["<<START_DATE_OPTION>>"]   = $option["2"];
-    $tag["<<START_HOUR_OPTION>>"]   = $option["3"];
-    $tag["<<START_MINUTE_OPTION>>"] = $option["4"];
-    $tag["<<START_SECOND_OPTION>>"] = $option["5"];
 
-    /* λ֤Υ쥯ȥܥå */
-    $option = array("0" => "",
-                    "1" => "",
-                    "2" => "",
-                    "3" => "",
-                    "4" => "",
-                    "5" => ""
-                   );
-    if (isset($_POST["endtime"]) === TRUE) {
-        $endtime =$_POST["endtime"];
-    } else {
-        $endtime = array("0" => -2,
-                         "1" => -2,
-                         "2" => -2,
-                         "3" => -2,
-                         "4" => -2,
-                         "5" => -2
-                        );
+    $tag["<<ENDDATE>>"] = date("Y/m/d 23:59:59");
+    if (isset($_POST["enddate"]) === TRUE) {
+        $tag["<<ENDDATE>>"] = $_POST["enddate"];
+    }
+
+    $tag["<<DEFLINE>>"] = $web_conf["sylas"]["displaylines"];
+    if (isset($_POST["resultline"])) {
+        $tag["<<DEFLINE>>"] = $_POST["resultline"];
+    }
+
+    $tag["<<DEFLINE>>"] = $web_conf["sylas"]["displaylines"];
+    if (isset($_POST["resultline"])) {
+        $tag["<<DEFLINE>>"] = $_POST["resultline"];
     }
-    make_time_select_option($endtime, $option);
-    $tag["<<END_YEAR_OPTION>>"]     = $option["0"];
-    $tag["<<END_MONTH_OPTION>>"]    = $option["1"];
-    $tag["<<END_DATE_OPTION>>"]     = $option["2"];
-    $tag["<<END_HOUR_OPTION>>"]     = $option["3"];
-    $tag["<<END_MINUTE_OPTION>>"]   = $option["4"];
-    $tag["<<END_SECOND_OPTION>>"]   = $option["5"];
 
     return TRUE;
 }
@@ -170,21 +138,11 @@ function make_hidden($post, &$tag)
     $ip   = escape_html($post["ip"]);
     $mac    = escape_html($post["mac"]);
     $interface = escape_html($post["interface"]);
-    $start      = $post["starttime"];
-    $end        = $post["endtime"];
-    $s_year     = $start[0];
-    $s_month    = $start[1];
-    $s_date     = $start[2];
-    $s_hour     = $start[3];
-    $s_minute   = $start[4];
-    $s_second   = $start[5];
-    $e_year     = $end[0];
-    $e_month    = $end[1];
-    $e_date     = $end[2];
-    $e_hour     = $end[3];
-    $e_minute   = $end[4];
-    $e_second   = $end[5];
+    $start      = $post["startdate"];
+    $end        = $post["enddate"];
     $sesskey    = escape_html($post["sk"]);
+    $resultline = $post["resultline"];
+
     $hidden = <<<EOD
 <form method="post" name="search_condition">
   <input type="hidden" name="page">
@@ -192,19 +150,10 @@ function make_hidden($post, &$tag)
   <input type="hidden" name="ip" value="$ip">
   <input type="hidden" name="mac" value="$mac">
   <input type="hidden" name="interface" value="$interface">
-  <input type="hidden" name="starttime[0]" value="$s_year">
-  <input type="hidden" name="starttime[1]" value="$s_month">
-  <input type="hidden" name="starttime[2]" value="$s_date">
-  <input type="hidden" name="starttime[3]" value="$s_hour">
-  <input type="hidden" name="starttime[4]" value="$s_minute">
-  <input type="hidden" name="starttime[5]" value="$s_second">
-  <input type="hidden" name="endtime[0]" value="$e_year">
-  <input type="hidden" name="endtime[1]" value="$e_month">
-  <input type="hidden" name="endtime[2]" value="$e_date">
-  <input type="hidden" name="endtime[3]" value="$e_hour">
-  <input type="hidden" name="endtime[4]" value="$e_minute">
-  <input type="hidden" name="endtime[5]" value="$e_second">
+  <input type="hidden" name="startdate" value="$start">
+  <input type="hidden" name="enddate" value="$end">
   <input type="hidden" name="sk" value="$sesskey">
+  <input type="hidden" name="resultline" value="$resultline">
   <input type="hidden" name="search_button" value="search">
 </form>
     
@@ -235,8 +184,8 @@ function set_loop_tag($result, $page, &$looptag, $sesskey, $post, &$k)
     global $web_conf;
 
     /* 롼ץ */
-    $start = ($page - 1) * $web_conf['sylas']['displaylines'];
-    $end   = ($page * $web_conf['sylas']['displaylines']) - 1;
+    $start = ($page - 1) * $_POST["resultline"];
+    $end   = ($page * $_POST["resultline"]) - 1;
 
     $i = 0;
     $k = 0;
@@ -298,19 +247,9 @@ function set_loop_tag($result, $page, &$looptag, $sesskey, $post, &$k)
            $looptag[$k]["<<E_SESS>>"] = $sesskey;
            $looptag[$k]["<<E_MAC>>"] = $log_mac;
            $looptag[$k]["<<E_LOG>>"] = $post["loggroup"];
-           $looptag[$k]["<<E_SY>>"] = $e_year;
-           $looptag[$k]["<<E_SM>>"] = $e_mon;
-           $looptag[$k]["<<E_SD>>"] = $e_day;
-           $looptag[$k]["<<E_SH>>"] = $e_hour;
-           $looptag[$k]["<<E_SMI>>"] = $e_min;
-           $looptag[$k]["<<E_SS>>"] = $e_sec;
-
-           $looptag[$k]["<<S_SY>>"] = $s_year;
-           $looptag[$k]["<<S_SM>>"] = $s_mon;
-           $looptag[$k]["<<S_SD>>"] = $s_day;
-           $looptag[$k]["<<S_SH>>"] = $s_hour;
-           $looptag[$k]["<<S_SMI>>"] = $s_min;
-           $looptag[$k]["<<S_SS>>"] = $s_sec;
+           $looptag[$k]["<<S_D>>"] = $post["startdate"];
+           $looptag[$k]["<<E_D>>"] = $post["enddate"];
+           $looptag[$k]["<<RL>>"] = $web_conf["sylas"]["displaylines"];
 
            $k++;
        }
