@@ -62,21 +62,10 @@ function make_hidden($post, &$tag)
     $priority   = $post["priority"];
     $keyword    = escape_html($post["keyword"]);
     $searchtype = $post["searchtype"];
-    $start      = $post["starttime"];
-    $end        = $post["endtime"];
-    $s_year     = $start[0];
-    $s_month    = $start[1];
-    $s_date     = $start[2];
-    $s_hour     = $start[3];
-    $s_minute   = $start[4];
-    $s_second   = $start[5];
-    $e_year     = $end[0];
-    $e_month    = $end[1];
-    $e_date     = $end[2];
-    $e_hour     = $end[3];
-    $e_minute   = $end[4];
-    $e_second   = $end[5];
+    $start      = $post["startdate"];
+    $end        = $post["enddate"];
     $sesskey    = escape_html($post["sk"]);
+    $resultline = $post["resultline"];
 
     $hidden = <<<EOD
 <form method="post" name="search_condition">
@@ -86,19 +75,10 @@ function make_hidden($post, &$tag)
   <input type="hidden" name="priority" value="$priority">
   <input type="hidden" name="keyword" value="$keyword">
   <input type="hidden" name="searchtype" value="$searchtype">
-  <input type="hidden" name="starttime[0]" value="$s_year">
-  <input type="hidden" name="starttime[1]" value="$s_month">
-  <input type="hidden" name="starttime[2]" value="$s_date">
-  <input type="hidden" name="starttime[3]" value="$s_hour">
-  <input type="hidden" name="starttime[4]" value="$s_minute">
-  <input type="hidden" name="starttime[5]" value="$s_second">
-  <input type="hidden" name="endtime[0]" value="$e_year">
-  <input type="hidden" name="endtime[1]" value="$e_month">
-  <input type="hidden" name="endtime[2]" value="$e_date">
-  <input type="hidden" name="endtime[3]" value="$e_hour">
-  <input type="hidden" name="endtime[4]" value="$e_minute">
-  <input type="hidden" name="endtime[5]" value="$e_second">
+  <input type="hidden" name="startdate" value="$start">
+  <input type="hidden" name="enddate" value="$end">
   <input type="hidden" name="sk" value="$sesskey">
+  <input type="hidden" name="resultline" value="$resultline">
 </form>
 
 EOD;
@@ -124,8 +104,8 @@ function set_loop_tag($data, $page, &$looptag)
     global $web_conf;
 
     /* 롼ץ */
-    $start = ($page - 1) * $web_conf['sylas']['displaylines'];
-    $end   = ($page * $web_conf['sylas']['displaylines']) - 1;
+    $start = ($page - 1) * $_POST["resultline"];
+    $end   = ($page * $_POST["resultline"]) - 1;
 
     $i = 0;
     $k = 0;
@@ -236,51 +216,22 @@ EOD;
                     "4" => "",
                     "5" => ""
                    );
-    if (isset($_POST["starttime"]) === TRUE) {
-        $starttime =$_POST["starttime"];
-    } else {
-        $starttime = array("0" => -2,
-                           "1" => -2,
-                           "2" => -2,
-                           "3" => -2,
-                           "4" => -2,
-                           "5" => -2
-                          );
-    }
-    make_time_select_option($starttime, $option);
-    $tag["<<START_YEAR_OPTION>>"]   = $option["0"];
-    $tag["<<START_MONTH_OPTION>>"]  = $option["1"];
-    $tag["<<START_DATE_OPTION>>"]   = $option["2"];
-    $tag["<<START_HOUR_OPTION>>"]   = $option["3"];
-    $tag["<<START_MINUTE_OPTION>>"] = $option["4"];
-    $tag["<<START_SECOND_OPTION>>"] = $option["5"];
 
-    /* λ֤Υ쥯ȥܥå */
-    $option = array("0" => "",
-                    "1" => "",
-                    "2" => "",
-                    "3" => "",
-                    "4" => "",
-                    "5" => ""
-                   );
-    if (isset($_POST["endtime"]) === TRUE) {
-        $endtime =$_POST["endtime"];
-    } else {
-        $endtime = array("0" => -2,
-                         "1" => -2,
-                         "2" => -2,
-                         "3" => -2,
-                         "4" => -2,
-                         "5" => -2
-                        );
+
+    $tag["<<STARTDATE>>"] = date("Y/m/d 00:00:00");
+    if (isset($_POST["startdate"]) === TRUE) {
+        $tag["<<STARTDATE>>"] = $_POST["startdate"];
+    }
+
+    $tag["<<ENDDATE>>"] = date("Y/m/d 23:59:59");
+    if (isset($_POST["enddate"]) === TRUE) {
+        $tag["<<ENDDATE>>"] = $_POST["enddate"];
+    }
+
+    $tag["<<DEFLINE>>"] = $web_conf["sylas"]["displaylines"];
+    if (isset($_POST["resultline"])) {
+        $tag["<<DEFLINE>>"] = $_POST["resultline"];
     }
-    make_time_select_option($endtime, $option);
-    $tag["<<END_YEAR_OPTION>>"]     = $option["0"];
-    $tag["<<END_MONTH_OPTION>>"]    = $option["1"];
-    $tag["<<END_DATE_OPTION>>"]     = $option["2"];
-    $tag["<<END_HOUR_OPTION>>"]     = $option["3"];
-    $tag["<<END_MINUTE_OPTION>>"]   = $option["4"];
-    $tag["<<END_SECOND_OPTION>>"]   = $option["5"];
 
     return TRUE;
 }
@@ -297,14 +248,28 @@ EOD;
  **********************************************************/
 function printCSV($data)
 {
+    global $web_conf;
+
+    $keymap = array("msg"=>"Message",
+                    "host"=>"FromHost",
+                    "date"=>"DeviceReportedTime",
+                   );
+
+    $order = explode(",", $web_conf["sylas"]["csvformat"]);
+
     /* ̤1鷺Ľ */
     foreach ($data as $result) {
+        $line = array();
+
         /* ֥륯Ȥ򥨥 */
         $result = str_replace('"', '""', $result);
-        /* Ǥ֥륯ȤǰϤ */
-        array_walk ($result, function ($value) {$value = "\"$value\"";});
+
+        foreach ($order as $key) {
+            $line[] = '"'. $result[$keymap[$key]]. '"';
+        }
+
         /* ޶ڤǤĤʤƽ */
-        print implode(",", $result);
+        print implode(",", $line);
         print "\r\n";
     }
 
